==> 1.0.3.tar.gz: lib/model/country.dart <==
part of forestvpn_api.api;

class Country {
  
  String code = null;
  
  String printableName = null;
  
  String name = null;
  Country();

  @override
  String toString() {
    return 'Country[code=$code, printableName=$printableName, name=$name, ]';
  }

  Country.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    code = json['code'];
    printableName = json['printable_name'];
    name = json['name'];
  }

  Map<String, dynamic> toJson() {
    Map <String, dynamic> json = {};
    if (code != null)
      json['code'] = code;
    if (printableName != null)
      json['printable_name'] = printableName;
    if (name != null)
      json['name'] = name;
    return json;
  }

  static List<Country> listFromJson(List<dynamic> json) {
    return json == null ? List<Country>() : json.map((value) => Country.fromJson(value)).toList();
  }

  static Map<String, Country> mapFromJson(Map<String, dynamic> json) {
    var map = Map<String, Country>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) => map[key] = Country.fromJson(value));
    }
    return map;
  }

  // maps a json object with a list of Country-objects as value to a dart map
  static Map<String, List<Country>> mapListFromJson(Map<String, dynamic> json) {
    var map = Map<String, List<Country>>();
     if (json != null && json.isNotEmpty) {
       json.forEach((String key, dynamic value) {
         map[key] = Country.listFromJson(value);
       });
     }
     return map;
  }
}

==> 1.1.1.tar.gz: lib/model/country.dart <==
part of forestvpn_api.api;

class Country {
  
  String code = null;
  
  String printableName = null;
  
  String name = null;
  
  String emoji = null;
  Country();

  @override
  String toString() {
    return 'Country[code=$code, printableName=$printableName, name=$name, emoji=$emoji, ]';
  }

  Country.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    code = json['code'];
    printableName = json['printable_name'];
    name = json['name'];
    emoji = json['emoji'];
  }

  Map<String, dynamic> toJson() {
    Map <String, dynamic> json = {};
    if (code != null)
      json['code'] = code;
    if (printableName != null)
      json['printable_name'] = printableName;
    if (name != null)
      json['name'] = name;
    if (emoji != null)
      json['emoji'] = emoji;
    return json;
  }

  static List<Country> listFromJson(List<dynamic> json) {
    return json == null ? List<Country>() : json.map((value) => Country.fromJson(value)).toList();
  }

  static Map<String, Country> mapFromJson(Map<String, dynamic> json) {
    var map = Map<String, Country>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) => map[key] = Country.fromJson(value));
    }
    return map;
  }

  // maps a json object with a list of Country-objects as value to a dart map
  static Map<String, List<Country>> mapListFromJson(Map<String, dynamic> json) {
    var map = Map<String, List<Country>>();
     if (json != null && json.isNotEmpty) {
       json.forEach((String key, dynamic value) {
         map[key] = Country.listFromJson(value);
       });
     }
     return map;
  }
}
